Clojure only.

jj.bettong.capability.google

Searching through google.

Searching through google.
raw docstring

googleclj

(google)
(google opts)

A google_search capability.

Needs :api-key (or GOOGLE_API_KEY) and :cx (or GOOGLE_CSE_ID), the id of a Programmable Search Engine set to search the entire web. Google caps a request at 10 results.

Shared options: :max-results (5), :snippet-length, :timeout-ms, :base-url, :instructions, :description.

A `google_search` capability.

Needs :api-key (or GOOGLE_API_KEY) and :cx (or GOOGLE_CSE_ID), the id of a Programmable Search Engine set to search the entire web. Google caps a request at 10 results.

Shared options: :max-results (5), :snippet-length, :timeout-ms, :base-url,
:instructions, :description.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries