jj.bettong.llm

Thin client for the DeepSeek chat-completions API (OpenAI-compatible).

Thin client for the DeepSeek chat-completions API (OpenAI-compatible).
raw docstring

api-keyclj

(api-key k)

The API key to use, from the argument or the DEEPSEEK_API_KEY env var.

The API key to use, from the argument or the DEEPSEEK_API_KEY env var.
raw docstring

chatclj

(chat {:keys [messages tools model base-url api-key timeout-ms temperature]})

Sends messages (and optional tools) to the model, returns the assistant message map: {:role "assistant" :content ... :tool_calls [...]}.

Sends `messages` (and optional `tools`) to the model, returns the assistant
message map: {:role "assistant" :content ... :tool_calls [...]}.
raw docstring

default-base-urlclj


default-modelclj


parse-responseclj

(parse-response body)

Pulls the assistant message out of a chat-completions response body.

Pulls the assistant message out of a chat-completions response body.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries