Searching through duckduckgo.
Searching through duckduckgo.
(duckduckgo)(duckduckgo opts)A duckduckgo_search capability.
No API key. It scrapes DuckDuckGo's no-JavaScript endpoint, which sometimes answers a scraper with a challenge page instead of results.
Shared options: :max-results (5), :snippet-length, :timeout-ms, :base-url, :instructions, :description.
A `duckduckgo_search` capability. No API key. It scrapes DuckDuckGo's no-JavaScript endpoint, which sometimes answers a scraper with a challenge page instead of results. Shared options: :max-results (5), :snippet-length, :timeout-ms, :base-url, :instructions, :description.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |