Clojure only.

jj.bettong.cli

CLI entry point. Grants a writable filesystem and a shell - the explicit opt-in a program has to make, since reading is all a capability gives by default: lein run "Create file /tmp/foo.txt with content 'foo'"

CLI entry point. Grants a writable filesystem and a shell - the explicit
opt-in a program has to make, since reading is all a capability gives by default:
  lein run "Create file /tmp/foo.txt with content 'foo'"
raw docstring

-mainclj

(-main & args)

cljdoc builds & hosts documentation for Clojure/Script libraries