CLI entry point. Grants a writable filesystem and a shell - the explicit opt-in a program has to make, since reading is all a capability gives by default: lein run "Create file /tmp/foo.txt with content 'foo'"
CLI entry point. Grants a writable filesystem and a shell - the explicit opt-in a program has to make, since reading is all a capability gives by default: lein run "Create file /tmp/foo.txt with content 'foo'"
(-main & args)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |