Thin client for the DeepSeek chat-completions API (OpenAI-compatible).
Thin client for the DeepSeek chat-completions API (OpenAI-compatible).
(api-key k)The API key to use, from the argument or the DEEPSEEK_API_KEY env var.
The API key to use, from the argument or the DEEPSEEK_API_KEY env var.
(chat {:keys [messages tools model base-url api-key timeout-ms temperature]})Sends messages (and optional tools) to the model, returns the assistant
message map: {:role "assistant" :content ... :tool_calls [...]}.
Sends `messages` (and optional `tools`) to the model, returns the assistant
message map: {:role "assistant" :content ... :tool_calls [...]}.(parse-response body)Pulls the assistant message out of a chat-completions response body.
Pulls the assistant message out of a chat-completions response body.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |